import keras
import random

from keras.layers import Layer

class Stroke(Layer):

    def __init__(self, previous_layer=None, volatility_ratio=.1):
        super(Stroke, self).__init__()
        self.player = previous_layer
        self.num_outputs = previous_layer.output_shape[-1]
        self.vratio = volatility_ratio

    def call(self, input):
        weights = self.kernel
        num_weights = len(weights)
        for stricken in range(0, int(num_weights * self.vratio)):
            index = random.randint(0, num_weights)
            weights[index] = random.uniform(-.05, .05)
        self.set_weights(weights)
        return input

    def build(self, input_shape):
        weights = self.player.get_weights()
        self.kernel = weights
        super(Stroke, self).build(input_shape)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
     name='kerastroke',
     version='0.1.5',
     scripts=['kerastroke.py','__init__.py'] ,
     author="Charles Averill",
     author_email="charlesaverill20@gmail.com",
     description="A custom Keras layer to prevent overfitting",
     long_description=long_description,
     install_requires=['keras'],
   long_description_content_type="text/markdown",
     url="https://github.com/CharlesAverill/research",
     packages=setuptools.find_packages(),
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
 )
